diff mbox series

[for-8.0,5/9] pci: Use device_cold_reset() and bus_cold_reset()

Message ID 20221104161513.2455862-6-peter.maydell@linaro.org
State Handled Elsewhere
Headers show
Series reset: Remove some deprecated APIs | expand

Commit Message

Peter Maydell Nov. 4, 2022, 4:15 p.m. UTC
In the PCI subsystem we currently use the legacy function
qdev_reset_all() and qbus_reset_all().  These perform a recursive
reset, starting from either a qbus or a qdev.  However they do not
permit any of the devices in the tree to use three-phase reset,
because device reset goes through the device_legacy_reset() function
that only calls the single DeviceClass::reset method.

Switch to using the device_cold_reset() and bus_cold_reset()
functions.  These also perform a recursive reset, where first the
children are reset and then finally the parent, but they use the new
(...in 2020...) Resettable mechanism, which supports both the old
style single-reset method and also the new 3-phase reset handling.

This should be a no-behaviour-change commit which just reduces the
use of a deprecated API.

Commit created with:
 sed -i -e 's/qdev_reset_all/device_cold_reset/g;s/qbus_reset_all/bus_cold_reset/g' hw/pci/*.c

Signed-off-by: Peter Maydell <peter.maydell@linaro.org>
---
 hw/pci/pci.c        | 6 +++---
 hw/pci/pci_bridge.c | 2 +-
 2 files changed, 4 insertions(+), 4 deletions(-)

Comments

Philippe Mathieu-Daudé Nov. 4, 2022, 5:39 p.m. UTC | #1
On 4/11/22 17:15, Peter Maydell wrote:
> In the PCI subsystem we currently use the legacy function
> qdev_reset_all() and qbus_reset_all().  These perform a recursive
> reset, starting from either a qbus or a qdev.  However they do not
> permit any of the devices in the tree to use three-phase reset,
> because device reset goes through the device_legacy_reset() function
> that only calls the single DeviceClass::reset method.
> 
> Switch to using the device_cold_reset() and bus_cold_reset()
> functions.  These also perform a recursive reset, where first the
> children are reset and then finally the parent, but they use the new
> (...in 2020...) Resettable mechanism, which supports both the old
> style single-reset method and also the new 3-phase reset handling.
> 
> This should be a no-behaviour-change commit which just reduces the
> use of a deprecated API.
> 
> Commit created with:
>   sed -i -e 's/qdev_reset_all/device_cold_reset/g;s/qbus_reset_all/bus_cold_reset/g' hw/pci/*.c
> 
> Signed-off-by: Peter Maydell <peter.maydell@linaro.org>
> ---
>   hw/pci/pci.c        | 6 +++---
>   hw/pci/pci_bridge.c | 2 +-
>   2 files changed, 4 insertions(+), 4 deletions(-)

Reviewed-by: Philippe Mathieu-Daudé <philmd@linaro.org>
diff --git a/hw/pci/pci_bridge.c b/hw/pci/pci_bridge.c
index da34c8ebcd1..b2b180edd61 100644
--- a/hw/pci/pci_bridge.c
+++ b/hw/pci/pci_bridge.c
@@ -275,7 +275,7 @@  void pci_bridge_write_config(PCIDevice *d,
     newctl = pci_get_word(d->config + PCI_BRIDGE_CONTROL);
     if (~oldctl & newctl & PCI_BRIDGE_CTL_BUS_RESET) {
         /* Trigger hot reset on 0->1 transition. */
-        qbus_reset_all(BUS(&s->sec_bus));
+        bus_cold_reset(BUS(&s->sec_bus));
     }
 }
diff mbox series

Patch

diff --git a/hw/pci/pci.c b/hw/pci/pci.c
index 2f450f6a728..9d819cbe3b3 100644
--- a/hw/pci/pci.c
+++ b/hw/pci/pci.c
@@ -378,14 +378,14 @@  static void pci_do_device_reset(PCIDevice *dev)
  */
 void pci_device_reset(PCIDevice *dev)
 {
-    qdev_reset_all(&dev->qdev);
+    device_cold_reset(&dev->qdev);
     pci_do_device_reset(dev);
 }
 
 /*
  * Trigger pci bus reset under a given bus.
  * Called via qbus_reset_all on RST# assert, after the devices
  * have been reset qdev_reset_all-ed already.
  */
 static void pcibus_reset(BusState *qbus)
 {
@@ -378,14 +378,14 @@  static void pci_do_device_reset(PCIDevice *dev)
 /*
  * Trigger pci bus reset under a given bus.
- * Called via qbus_reset_all on RST# assert, after the devices
- * have been reset qdev_reset_all-ed already.
+ * Called via bus_cold_reset on RST# assert, after the devices
+ * have been reset device_cold_reset-ed already.
  */
 static void pcibus_reset(BusState *qbus)